
__version__ = "0.13rc6"
__version_vcs_info__ = {
    'branch': 'release-0.13',
    'revid': '675e9b6',
    'revno': 2407}
__version_user_email__ = "saxtouri@admin.grnet.gr"
__version_user_name__ = "Stavros Sachtouris"
